.. This is part of the Photini documentation.
   Copyright (C)  2012-15  Jim Easterbrook.
   See the file DOC_LICENSE.txt for copying condidions.

Photini documentation
=====================

.. toctree::
   :maxdepth: 2

   introduction
   misc/index
   installation
   manual/index
   workflow
   reading

Copyright (C)  2012-15  Jim Easterbrook.

Permission is granted to copy, distribute and/or modify this document under the terms of the GNU Free Documentation License, Version 1.3 or any later version published by the Free Software Foundation; with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
A copy of the license is included in the section entitled "GNU Free Documentation License".
